[![Documentation Status](https://readthedocs.org/projects/fafbseg-py/badge/?version=latest)](https://fafbseg-py.readthedocs.io/en/latest/?badge=latest) [![DOI](https://zenodo.org/badge/197735091.svg)](https://zenodo.org/badge/latestdoi/197735091)

# FAFBseg
Tools to work with manually generated and auto-segmented data in FAFB.

## Documentation
FAFBseg is on [readthedocs](https://fafbseg-py.readthedocs.io/en/latest/).

## Quickstart
Latest stable version

```bash
pip3 install fafbseg
```

Install from Github
```bash
pip3 install git+git://github.com/flyconnectome/fafbseg-py.git
```
